@@ -613,70 +613,103 @@ def remove_from_queue(speaker, action, args, soco_function, use_local_speaker_li
     queue = []
     for _ in range(speaker.queue_size):
         queue.append(1)
-
-    # Check for a list of items to remove
-    items = args[0].split(",")
-    for index in items:
-        # Check for a range ('x-y') instead of a single integer
-        if "-" in index:
-            rng = index.split("-")
-            if len(rng) != 2:
-                parameter_type_error(
-                    action, "two integers and a '-', e.g., '3-7' when using a range"
-                )
-                return False
-            try:
+    # Catch exceptions at the end
+    try:
+        # Create a list of items to remove based on the input args
+        # Mark these as '0'
+        items = args[0].split(",")
+        for index in items:
+            # Check for a range ('x-y') instead of a single integer
+            if "-" in index:
+                rng = index.split("-")
+                if len(rng) != 2:
+                    parameter_type_error(
+                        action, "two integers and a '-', e.g., '3-7' when using a range"
+                    )
+                    return False
                 index_1 = int(rng[0])
                 index_2 = int(rng[1])
-            except ValueError:
-                parameter_type_error(
-                    action, "two integers and a '-', e.g., '3-7' when using a range"
-                )
-                return False
-            if 1 <= index_1 <= len(queue) and 1 <= index_2 <= len(queue):
+                if index_1 < 1 or index_2 < 1:
+                    raise IndexError
                 if index_1 > index_2:
                     # Reverse the indices
                     index_2, index_1 = index_1, index_2
                 for i in range(index_1 - 1, index_2):
                     queue[i] = 0
             else:
-                error_and_exit(
-                    "Queue index(es) must be between 1 and the queue length ({})".format(
-                        len(queue)
-                    )
-                )
-                return False
-        else:
-            try:
                 index = int(index)
-            except ValueError:
-                parameter_type_error(
-                    action,
-                    "integer, or comma-separated integers without spaces (e.g., 3,7,4)",
-                )
-                return False
-            if 1 <= index <= len(queue):
+                if index < 1:
+                    raise IndexError
                 queue[index - 1] = 0
-            else:
-                error_and_exit(
-                    "Queue index(es) must be between 1 and {}".format(len(queue))
-                )
-                return False
-    logging.info("Created list of queue items to delete (==0) {}".format(queue))
+    # Exception handling
+    # Catch any non-integer input values
+    except ValueError:
+        parameter_type_error(
+            action, "integer, or comma-separated integers without spaces (e.g., 3,7,4)",
+        )
+        return False
+    # Catch any out-of-range values
+    except IndexError:
+        error_and_exit(
+            "Queue index(es) must be between 1 and {} (inclusive)".format(len(queue))
+        )
+        return False
     # Walk though the list of tracks from position 1, removing items marked '0'
     # Account for the queue shift by keeping count of those deleted
+    logging.info("Created map of queue items to delete (==0) {}".format(queue))
     count_removed = 0
     for item in range(len(queue)):
         if queue[item] == 0:
             updated_index = item - count_removed
             speaker.remove_from_queue(updated_index)
             logging.info(
-                "Removing queue item (adjusted) index {}".format(updated_index + 1)
+                "Removing queue item at (adjusted) index {}".format(updated_index + 1)
             )
             count_removed += 1
     return True
 
 
+@zero_parameters
+def remove_current_track_from_queue(
+    speaker, action, args, soco_function, use_local_speaker_list
+):
+    if speaker.queue_size == 0:
+        error_and_exit("No tracks in queue")
+        return False
+    current_track = int(speaker.get_current_track_info()["playlist_position"])
+    logging.info("Removing track {}".format(current_track))
+    speaker.remove_from_queue(current_track - 1)
+    return True
+
+
+@zero_or_one_parameter
+def remove_last_track_from_queue(
+    speaker, action, args, soco_function, use_local_speaker_list
+):
+    queue_size = speaker.queue_size
+    logging.info("Queue size is {}".format(queue_size))
+    if queue_size == 0:
+        error_and_exit("No tracks in queue")
+        return False
+    if len(args) == 1:
+        try:
+            count = int(args[0])
+        except ValueError:
+            parameter_type_error(action, "an integer > 1")
+        if not 1 <= count <= queue_size:
+            error_and_exit("parameter must be between 1 and {}".format(queue_size))
+            return False
+    else:
+        count = 1
+    logging.info("Removing the last {} tracks from the queue".format(count))
+    while count > 0:
+        logging.info("Removing track {}".format(queue_size))
+        speaker.remove_from_queue(queue_size - 1)
+        queue_size -= 1
+        count -= 1
+    return True
+
+
 @one_parameter
 def save_queue(speaker, action, args, soco_function, use_local_speaker_list):
     speaker.create_sonos_playlist_from_queue(args[0])
@@ -1284,6 +1317,7 @@ actions = {
     "mute": SonosFunction(on_off_action, "mute"),
     "cross_fade": SonosFunction(on_off_action, "cross_fade"),
     "crossfade": SonosFunction(on_off_action, "cross_fade"),
+    "fade": SonosFunction(on_off_action, "cross_fade"),
     "loudness": SonosFunction(on_off_action, "loudness"),
     "status_light": SonosFunction(on_off_action, "status_light"),
     "light": SonosFunction(on_off_action, "status_light"),
@@ -1458,4 +1492,10 @@ actions = {
     "sh": SonosFunction(shuffle, ""),
     "repeat": SonosFunction(repeat, ""),
     "rpt": SonosFunction(repeat, ""),
+    "remove_current_track_from_queue": SonosFunction(
+        remove_current_track_from_queue, ""
+    ),
+    "rctfq": SonosFunction(remove_current_track_from_queue, ""),
+    "remove_last_track_from_queue": SonosFunction(remove_last_track_from_queue, ""),
+    "rltfq": SonosFunction(remove_last_track_from_queue, ""),
 }
