@@ -1,18 +1,13 @@
 import datetime
 import logging
 import os
-import platform
 import sys
+from signal import SIGTERM
 from collections.abc import Sequence
 import soco
 from .__init__ import __version__
 from .speakers import Speakers
 
-if "Windows" not in platform.platform():
-    from signal import SIGKILL
-else:
-    from signal import SIGTERM
-
 
 # Error handling
 def error_and_exit(msg):
@@ -182,13 +177,13 @@ def version():
     print("soco version:     {}".format(soco.__version__))
 
 
-# ToDo: Remove with SIGKILL fix
-use_sigkill = False
+# ToDo: Remove with SIGTERM fix
+use_sigterm = False
 
 
-def set_sigkill(sigkill):
-    global use_sigkill
-    use_sigkill = sigkill
+def set_sigterm(sigterm):
+    global use_sigterm
+    use_sigterm = sigterm
 
 
 def sig_handler(signal_received, frame):
@@ -198,10 +193,10 @@ def sig_handler(signal_received, frame):
     # ToDo: Temporary for now; hard kill required to get out of 'wait_for_stopped'
     #       Need to understand this.
     #       Not tested on Windows
-    if "Windows" not in platform.platform() and use_sigkill:
-        os.kill(os.getpid(), SIGKILL)
-    else:
+    if use_sigterm:
         os.kill(os.getpid(), SIGTERM)
+    else:
+        exit(0)
 
 
 class RewindableList(Sequence):
@@ -286,3 +281,35 @@ def get_speaker(name, local=False):
     else:
         logging.info("Using SoCo speaker discovery")
         return soco.discovery.by_name(name)
+
+
+# Argument processing
+def configure_common_args(parser):
+    """Set up the optional arguments common across the command line programs"""
+    parser.add_argument(
+        "--network-discovery-threads",
+        "-t",
+        type=int,
+        default=128,
+        help="Maximum number of threads used for Sonos network discovery",
+    )
+    parser.add_argument(
+        "--network-discovery-timeout",
+        "-n",
+        type=float,
+        default=2.0,
+        help="Network timeout for Sonos device scan (seconds)",
+    )
+    parser.add_argument(
+        "--version",
+        "-v",
+        action="store_true",
+        default=False,
+        help="Print the soco-cli and SoCo versions and exit",
+    )
+    parser.add_argument(
+        "--log",
+        type=str,
+        default="NONE",
+        help="Set the logging level: 'NONE' (default) |'CRITICAL' | 'ERROR' | 'WARN'| 'INFO' | 'DEBUG'",
+    )
